@@ -2,6 +2,7 @@ package Example::Controller::Root;
 
 use Moose;
 use MooseX::MethodAttributes;
+use CatalystX::Utils::HttpException;
 
 extends 'Catalyst::Controller';
 
@@ -16,6 +17,10 @@ sub root :Chained(/) PathPart('') CaptureArgs(0) {}
     die "saefdsdfsfs";
   }
 
+  sub throw :Chained(root) PathPart(throw) Args(0) {
+    throw_http 400, errors=>[1,2,3],  
+  }
+
 sub end :Does(RenderErrors) { }
 
 __PACKAGE__->config(namespace=>'');
