@@ -2,8 +2,8 @@ package Catalyst::View::Errors::JSON;
 
 use Moose;
 use JSON::MaybeXS;
-use Catalyst::Utils::ContentNegotiation;
-use Catalyst::Utils::ErrorMessages;
+use CatalystX::Utils::ContentNegotiation;
+use CatalystX::Utils::ErrorMessages;
 
 extends 'Catalyst::View';
 
@@ -21,7 +21,7 @@ has cn => (
   is => 'ro',
   init_arg => undef,
   required => 1, 
-  default => sub { Catalyst::Utils::ContentNegotiation::content_negotiator },
+  default => sub { CatalystX::Utils::ContentNegotiation::content_negotiator },
 );
 
 has default_language => (is=>'ro', required=>1, default=>'en_US');
@@ -48,7 +48,7 @@ sub get_language {
 
 sub available_languages {
   my ($self, $c) = @_;
-  return my @lang_tags = Catalyst::Utils::ErrorMessages::available_languages;
+  return my @lang_tags = CatalystX::Utils::ErrorMessages::available_languages;
 }
 
 sub finalize_message_info {
@@ -73,7 +73,7 @@ sub finalize_message_info {
 
 sub get_message_info {
   my ($self, $c, $lang, $code) = @_;
-  return my $message_info_hash = Catalyst::Utils::ErrorMessages::get_message_info($lang, $code);
+  return my $message_info_hash = CatalystX::Utils::ErrorMessages::get_message_info($lang, $code);
 }
 
 sub render_json {
@@ -108,13 +108,13 @@ to change function.
 =head2 available_languages
 
 An array of the languages available for serving error responses.   By default we use
-L<Catalyst::Utils::ErrorMessages> but if you have your own list of translations you can override
+L<CatalystX::Utils::ErrorMessages> but if you have your own list of translations you can override
 this.
 
 =head2 get_message_info
 
 Return error message info by code and language.  By default we use
-L<Catalyst::Utils::ErrorMessages> but if you have your own list of translations you can override
+L<CatalystX::Utils::ErrorMessages> but if you have your own list of translations you can override
 this.
 
 =head2 finalize_message_info
